bbprep.Conformer
================

.. currentmodule:: bbprep

.. autoclass:: Conformer
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Conformer.permutation
      ~Conformer.source
      ~Conformer.molecule
      ~Conformer.conformer_id
   
   